==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24PropertyChangeHandler.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$PropertyChangeHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b9662b6275d731a3 javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$object *, struct _jc_java_beans_PropertyChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24PropertyChangeHandler.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$PropertyChangeHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b9662b6275d731a3 javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PropertyChangeHandler_H_ */
